@@ -35,7 +35,7 @@ class AtlantisClient:
 
         .. code-block:: python
 
-            from stl_sdk.torpedo import AtlantisClient
+            from stl_sdk.atlantis import AtlantisClient
 
             client = AtlantisClient('https://accounts.spacetimeanalytics.com', 'client_id_abc123', 'client_secret_123abc')
             token = client.issue_token('code123abc')
@@ -82,7 +82,7 @@ class AtlantisClient:
 
         .. code-block:: python
 
-            from stl_sdk.torpedo import AtlantisClient
+            from stl_sdk.atlantis import AtlantisClient
 
             client = AtlantisClient('https://accounts.spacetimeanalytics.com', 'client_id_abc123', 'client_secret_123abc')
             token_payload = client.validate_token('tokenJwT')
